@@ -1,6 +1,7 @@
 from . import util
 from .exceptions import KrankshaftError
 from .query import DjangoQuery
+from django.core.files import File
 from django.core.urlresolvers import reverse
 from django.db import models
 
@@ -9,16 +10,6 @@ try:
 except ImportError:
     from .compat.xact import xact as atomic
 
-# TODO serialize file fields...
-#   field: 'upload_to/file...',
-#   field_href: '/media/upload_to/file...',
-#
-#   how to update that field?
-#   should we strip upload_to?
-#   we don't want to expose the upload_to path because that's a server side
-#   setting... right?
-#   maybe it doesnt matter...
-#   how do we handle upload? just ignore the field?
 class DjangoModelResource(object):
     '''
     Expose a Django Model as a RESTful resource.  Default implementation
@@ -310,7 +301,15 @@ class DjangoModelResource(object):
         '''
         if not isinstance(query, self.Query):
             query = self.Query(query)
-        qs, meta = query.apply(self.get_query_set(request))
+
+        try:
+            qs, meta = query.apply(self.get_query_set(request))
+        except self.Query.Issues as exc:
+            self.api.abort(self.api.serialize(request, 403, {
+                'error': 'There are issues with your query',
+                'invalid': exc.errors,
+            }))
+
         instances = list(qs)
 
         if meta['next']:
@@ -358,7 +357,13 @@ class DjangoModelResource(object):
         qs = self.get_query_set(request)
         meta = None
         if query:
-            qs, meta = query.apply(qs)
+            try:
+                qs, meta = query.apply(qs)
+            except self.Query.Issues as exc:
+                self.api.abort(self.api.serialize(request, 403, {
+                    'error': 'There are issues with your query',
+                    'invalid': exc.errors,
+                }))
 
         try:
             instance = qs.get(pk=id)
@@ -638,6 +643,15 @@ class DjangoModelResource(object):
                     data[field.name + '_id'] = \
                         getattr(instance, field.name + '_id')
 
+                elif isinstance(field, models.FileField):
+                    try:
+                        data[field.name] = getattr(instance, field.name).name
+                        data[field.name + '_href'] = \
+                            getattr(instance, field.name).url
+                    except ValueError:
+                        data[field.name] = ''
+                        data[field.name + '_href'] = ''
+
                 else:
                     data[field.name] = getattr(instance, field.name)
 
@@ -651,6 +665,14 @@ class DjangoModelResource(object):
         Update an instance with clean()ed data specified in the request.
 
         No further saving is required after this has been called.
+
+        Note: to update models that require uploading content (file/image
+        uploads) you'll need to make the proper request enctype
+        (form-data/multipart).  Without this, the browser will not upload
+        the file.  The other caveat to this is using the API outside of a
+        browser context.  You cannot simply "upload" a file encoded in JSON
+        out of the box.  You must construct a form-data/multipart request and
+        use this encoding to upload a file.
         '''
         manytomany = {}
         for field in self.fields:
@@ -671,6 +693,11 @@ class DjangoModelResource(object):
                 elif isinstance(field, models.ForeignKey):
                     setattr(instance, field.name + '_id', clean[field.name])
 
+                elif isinstance(field, models.FileField):
+                    file = clean[field.name]
+                    getattr(instance, field.name) \
+                        .save(file.name, file, save=False)
+
                 else:
                     setattr(instance, field.name, clean[field.name])
 
